@@ -4,7 +4,7 @@ use 5.010001;
 
 package RT::Extension::REST2;
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 our $REST_PATH = '/REST/2.0';
 
 use Plack::Builder;
@@ -511,10 +511,11 @@ curl for SSL like --cacert.
 
 Below are some examples using the endpoints above.
 
-    # Create a ticket, setting some custom fields
+    # Create a ticket, setting some custom fields and a custom role
     curl -X POST -H "Content-Type: application/json" -u 'root:password'
         -d '{ "Queue": "General", "Subject": "Create ticket test",
             "Requestor": "user1@example.com", "Cc": "user2@example.com",
+            "CustomRoles": {"My Role": "staff1@example.com"},
             "Content": "Testing a create",
             "CustomFields": {"Severity": "Low"}}'
         'https://myrt.com/REST/2.0/ticket'
