@@ -5,7 +5,7 @@ use warnings;
 use Moose::Role;
 use namespace::autoclean;
 use JSON ();
-use RT::Extension::REST2::Util qw( deserialize_record error_as_json expand_uid update_custom_fields update_role_members);
+use RT::Extension::REST2::Util qw( deserialize_record error_as_json expand_uid update_custom_fields update_role_members fix_custom_role_ids );
 use List::MoreUtils 'uniq';
 
 with 'RT::Extension::REST2::Resource::Role::RequestBodyIsJSON'
@@ -253,6 +253,13 @@ sub create_record {
         }
     }
 
+    if ( $args{CustomRoles} ) {
+        # RT::Ticket::Create wants custom role IDs (like RT::CustomRole-ID)
+        # rather than role names.
+        %args = ( %args, %{ fix_custom_role_ids( $record, delete $args{CustomRoles} ) } );
+    }
+
+
     my $method = $record->isa('RT::Group') ? 'CreateUserDefinedGroup' : 'Create';
     my ($ok, @rest) = $record->$method(%args);
 
